@@ -192,10 +192,10 @@ def validateResponseArgs(model, user):
     if not user:
         raise ValueError("User input cannot be None or empty.")
 
-def validateVisionArgs(model, user, paths):
+def validateVisionArgs(model, user, files):
     validateResponseArgs(model, user)
-    if not paths or not isinstance(paths, list) or len(paths) == 0:
-        raise ValueError("paths must be a list with at least one item.")
+    if not files or not isinstance(files, list) or len(files) == 0:
+        raise ValueError("File paths must be a list with at least one item.")
 
 
 def parseModels(models):
@@ -233,7 +233,6 @@ def parseModels(models):
     raise TypeError("models must be a string, list/tuple, or dict.")
 
 
-
 def isStructured(obj):
     """
     Check if the input is a structured list of message dicts.
@@ -464,15 +463,18 @@ def safetySettings(**kwargs):
 
 
 #------------------------ Media ------------------------
-def extractImagePaths(text: str):
+def extractMediaInfo(text: str):
     """
     Extracts image file paths from a given text.
     Supports both Windows and Unix-style paths.
     Returns a list of matched image paths.
     """
-    win = r'([A-Za-z]:(?:\\|/).*?\.(?:png|jpe?g|gif|webp))'
-    unix = r'(/[^ ]*?/.*?\.(?:png|jpe?g|gif|webp))'
-    matches = re.findall(f"{win}|{unix}", text, re.IGNORECASE)
+    EXT = r'(?:png|jpe?g|gif|webp|bmp|tiff?)'
+    PATTERNS = {
+        "win": fr'([A-Za-z]:(?:\\|/).*?\.{EXT})',
+        "unix": fr'(/[^ ]*?/.*?\.{EXT})'
+    }
+    matches = re.findall(f"{PATTERNS['win']}|{PATTERNS['unix']}", text, re.IGNORECASE)
     return [p for pair in matches for p in pair if p]
 
 
@@ -562,6 +564,85 @@ def unsupportedFormat(ext):
     raise ValueError(f"File format '{ext}' is not supported for Vision frame extraction")
 
 
+#------------------------ Files ------------------------
+def extractFileInfo(text):
+    """
+    Uses extractDocPaths and extractText to produce a string like:
+    File 1:
+    [text of first file]
+    
+    File 2:
+    [text of second file]
+    etc.
+    """
+    filePaths = extractDocPaths(text)
+    extracted = extractText(filePaths)
+    return "\n\n".join(
+        f"File {i+1}:\n{extracted[path].strip()}" for i, path in enumerate(filePaths)
+    )
+
+
+def extractDocPaths(text: str):
+    """
+    Extracts document file paths from a given text.
+    Supports both Windows and Unix-style paths.
+    Returns a list of matched document paths.
+    """
+    # Supported extensions: doc, docx, pdf, txt, odt, rtf, xls, xlsx, ppt, pptx
+    EXT = r'(?:docx?|pdf|txt|odt|rtf|xlsx?|pptx?)'
+    PATTERNS = {
+        "win": fr'([A-Za-z]:(?:\\|/).*?\.{EXT})',
+        "unix": fr'(/[^ ]*?/.*?\.{EXT})'
+    }
+    # Compile and find matches
+    matches = re.findall(f"{PATTERNS['win']}|{PATTERNS['unix']}", text, re.IGNORECASE)
+    # Flatten tuples and filter empty strings
+    return [p for pair in matches for p in pair if p]
+
+
+def extractText(filePaths):
+    """
+    Extracts text from a single file or multiple files (str, list, or tuple).
+    Returns text if input is str; dict of {filePath: text} if list/tuple.
+    """
+    extractorMap = {
+        "pdf": _extractTextFromPdf,
+        "txt": _extractTextFromTxt,
+        "docx": _extractTextFromDocx
+    }
+
+    def extract(filePath):
+        ext = filePath.lower().split('.')[-1]
+        if ext not in extractorMap:
+            raise ValueError(f"Unsupported file type: {ext}")
+        return extractorMap[ext](filePath)
+
+    if isinstance(filePaths, (list, tuple)):
+        return {path: extract(path) for path in filePaths}
+    elif isinstance(filePaths, str):
+        return extract(filePaths)
+    else:
+        raise TypeError("filePaths must be a str, list, or tuple")
+
+
+import pdfplumber
+
+def _extractTextFromPdf(filePath):
+    with pdfplumber.open(filePath) as pdf:
+        return "\n".join(page.extract_text() or "" for page in pdf.pages)
+
+def _extractTextFromTxt(filePath):
+    with open(filePath, "r", encoding="utf-8", errors="ignore") as file:
+        return file.read()
+
+from docx import Document
+
+def _extractTextFromDocx(filePath):
+    doc = Document(filePath)
+    return "\n".join(para.text for para in doc.paragraphs)
+
+
+#------------------------ Reasoning Models ------------------------
 ANTHROPIC_MODELS = (
     "claude-3-7",
     "claude-sonnet-4",
