@@ -18,7 +18,7 @@
 #     parseModels,
 #     isStructured,
 #     safetySettings,
-#     extractImagePaths,
+#     extractMediaInfo,
 #     getFrames
 # )
 
@@ -66,7 +66,7 @@ from .HAIUtils.HAIUtils import (
     parseModels,
     isStructured,
     safetySettings,
-    extractImagePaths,
+    extractMediaInfo,
     getFrames
 )
 
@@ -219,6 +219,7 @@ class HoloAI:
             - tokens/max_tokens: (int) Max tokens to use (Optional (default: 3369)).
             - effort: (str) Effort level ('auto', 'low', 'medium', 'high') (Optional (default: 'auto')).
             - budget/max_budget: (int) Budget for the response (Optional (default: 1369)).
+            - files: (list) List of file paths can be past in manually or during runtime (default: empty list).
             - verbose: (bool) Return verbose output (Optional (default: False)).
         :return: A Response object, or a Vision object if image paths are found.
         """
@@ -243,6 +244,7 @@ class HoloAI:
             - tokens/max_tokens: (int) Max tokens to use (Optional (default: 3369)).
             - effort: (str) Effort level ('auto', 'low', 'medium', 'high') (Optional (default: 'auto')).
             - budget/max_budget: (int) Budget for the response (Optional (default: 1369)).
+            - files: (list) List of file paths can be past in manually or during runtime (default: empty list).
             - verbose: (bool) Return verbose output (Optional (default: False)).
         :return: A Response object, or a Vision object if image paths are found.
         """
@@ -261,6 +263,7 @@ class HoloAI:
             - tokens/max_tokens: (int) Max tokens to use (Optional (default: 3369)).
             - effort: (str) Effort level ('auto', 'low', 'medium', 'high') (Optional (default: 'auto')).
             - budget/max_budget: (int) Budget for the response (Optional (default: 1369)).
+            - files: (list) List of file paths can be past in manually or during runtime (default: empty list).
             - verbose: (bool) Return verbose output (Optional (default: False)).
         :return: A Response object.
         """
@@ -277,6 +280,7 @@ class HoloAI:
                 Both 'user' and 'input' are interchangeable; use either (Preferred: input).
             - tools: (list) Tools to use (Optional).
             - tokens/max_tokens: (int) Max tokens to use (Optional (default: 3369)).
+            - files: (list) List of file paths can be past in manually or during runtime (default: empty list).
             - verbose: (bool) Return verbose output (Optional (default: False)).
         :return: A Response object.
         """
@@ -292,7 +296,7 @@ class HoloAI:
                 Accepts a single prompt string or a message history (list of messages). 
                 Both 'user' and 'input' are interchangeable; use either (Preferred: input).
             - tokens/max_tokens: (int) Max tokens to use (Optional (default: 3369)).
-            - paths: (list) List of image paths (default: empty list).
+            - files: (list) List of image file paths (default: empty list).
             - collect: (int) Number of frames to collect (default: 10).
             - verbose: (bool) Return verbose output (Optional (default: False)).
         :return: A Vision response object.
@@ -313,7 +317,7 @@ class HoloAI:
             - tokens/max_tokens: (int) Max tokens to use (Optional (default: 3369)).
             - effort: (str) Effort level ('auto', 'low', 'medium', 'high') (Optional (default: 'auto')).
             - budget/max_budget: (int) Budget for the response (Optional (default: 1369)).
-            - paths: (list) List of image paths (default: empty list).
+            - files: (list) List of file paths can be past in manually or during runtime (default: empty list).
             - collect: (int) Number of frames to collect (default: 10).
             - verbose: (bool) Return verbose output (Optional (default: False)).
         :return: A Reasoning, Response, or Vision object.
@@ -349,17 +353,17 @@ class HoloAI:
             text = str(raw)
 
         # 2. Detect mode
-        imagePaths = extractImagePaths(text)
+        images = extractMediaInfo(text)
 
         # 3. Select mode
         def visionMode():
-            img = imagePaths[-1]
+            img = images[-1]
             promptOnly = re.split(re.escape(img), text)[0].strip()
-            return self._routeVision(
+            return self.Vision(
                 model=models['vision'],
                 system=system,
                 user=promptOnly,
-                paths=imagePaths,
+                files=images,
                 collect=5,
                 verbose=verbose
             )
@@ -374,7 +378,7 @@ class HoloAI:
             # Add more modes here, e.g., "audio": audioMode, etc.
         }
 
-        mode = "vision" if imagePaths else "response"
+        mode = "vision" if images else "response"
         return modeMap[mode]()
 
     def _routeResponse(self, **kwargs):
@@ -389,6 +393,9 @@ class HoloAI:
         kwargs = {k.lower(): v for k, v in kwargs.items()}
         model  = kwargs.get('model')
         config = self._getProviderConfig(model)
+        notice = kwargs.get('paths')
+        if notice:
+            print(f"[Notice] 'paths' is being deprecated in future releases, please use 'files' instead.")
         return config.getVision( **kwargs)
 
     def isStructured(self, obj):
@@ -483,10 +490,10 @@ class HoloAI:
         """
         return safetySettings(**kwargs)
 
-    def extractImagePaths(self, text: str):
+    def extractMediaInfo(self, text: str):
         """
         Extracts image file paths from a given text.
         Supports both Windows and Unix-style paths.
         Returns a list of matched image paths.
         """
-        return extractImagePaths(text)
+        return extractMediaInfo(text)
